@@ -9,7 +9,11 @@ class PermissionFlagMiddleware:
         self.switch_name = 'middleware'
 
     def __call__(self, request):
-        if not waffle.switch_is_active(self.switch_name):
-            raise ServiceUnavailable()
+        whitelisted_paths = ['dkutils', 'switches', 'debug']
         response = self.get_response(request)
+        if not waffle.switch_is_active(self.switch_name):
+            for path in whitelisted_paths:
+                if request.path in path:
+                    return response
+            raise ServiceUnavailable()
         return response
