@@ -19,11 +19,16 @@ class DebugSerializer(serializers.ModelSerializer):
                                      style={'input_type': 'password'})
     class Meta:
         model = User
-        fields = ('id', 'first_name', 'last_name', 'phone_number', 'username',
-                  'email', 'is_active', 'is_staff', 'password')
+        fields = ('id', 'phone_number', 'username', 'email', 'is_active', 'is_staff', 'password')
 
     def create(self, validated_data):
-        user = super().create(validated_data)
+        phone_number = validated_data['phone_number']
+        password = validated_data['password']
+        email = validated_data.get('email')
+        user = User.objects.create_superuser(phone_number=phone_number,
+                                             email=email,
+                                             password=password)
         user.type = User.STAFF
         user.is_superuser = user.is_active = user.is_staff = True
-        user.save()
\ No newline at end of file
+        user.save()
+        return user
